@@ -1,12 +1,16 @@
 from aiohttp.web import Response
-import ujson
+
+try:
+    import ujson as json
+except ImportError:
+    import json
 
 class JSON(Response):
     """Serialize response to JSON with aiohttp.web"""
 
-    def __init__(self, json, status=200,
+    def __init__(self, data, status=200,
                  reason=None, headers=None):
-        body = ujson.dumps(json).encode('utf-8')
+        body = json.dumps(data).encode('utf-8')
 
         super().__init__(body=body, status=status, reason=reason,
                          headers=headers, content_type='application/json')
\ No newline at end of file
